@@ -46,7 +46,7 @@ void reset_signals(void)
 
 int spawnv(int logpri, char *prog, char **argv) {
   pid_t f;
-  int status, nullfd, pipefd[2];
+  int status, pipefd[2];
   FILE *errs;
   char errbuf[1024], *p;
   sigset_t allsignals, oldsig;
@@ -60,10 +60,6 @@ int spawnv(int logpri, char *prog, char **argv) {
     f = fork();
   if ( f == 0 ) {
     reset_signals();
-    if ( (nullfd = open("/dev/null", O_RDONLY)) ) {
-      dup2(nullfd, STDIN_FILENO);
-      close(nullfd);
-    }
     close(pipefd[0]);
     dup2(pipefd[1], STDOUT_FILENO);
     dup2(pipefd[1], STDERR_FILENO);
