@@ -13,8 +13,18 @@
 #include <linux/module.h>
 #include "autofs_i.h"
 
+#if LINUX_VERSION_CODE < kver(2,1,36)
+#define __initfunc(X) X
+#else
+#include <linux/init.h>
+#endif
+
 static struct file_system_type autofs_fs_type = {
+#if LINUX_VERSION_CODE < kver(2,1,43)
 	autofs_read_super, "autofs", 0, NULL
+#else
+	"autofs", FS_NO_DCACHE, autofs_read_super, NULL
+#endif
 };
 
 #ifdef MODULE
